#ifndef NT2_INCLUDE_CONSTANTS_LDEXPMASK_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_LDEXPMASK_HPP_INCLUDED

#include <nt2/constant/include/constants/ldexpmask.hpp>

#endif
